summaryrefslogtreecommitdiff
path: root/lisp/gnus
diff options
context:
space:
mode:
authorMiles Bader <miles@gnu.org>2005-09-11 22:21:01 +0000
committerMiles Bader <miles@gnu.org>2005-09-11 22:21:01 +0000
commitff8d296438e69b8cf701d95b6ccd271c416c46fd (patch)
tree44b388101b40592656ad4c5033aabe2a1ae4b462 /lisp/gnus
parent389cb481135145b80a679beec8cdc8fed75682c5 (diff)
parenta8f6d239d2d541ec874a22000e0542c20fd55a67 (diff)
downloademacs-ff8d296438e69b8cf701d95b6ccd271c416c46fd.tar.gz
emacs-ff8d296438e69b8cf701d95b6ccd271c416c46fd.tar.bz2
emacs-ff8d296438e69b8cf701d95b6ccd271c416c46fd.zip
Revision: miles@gnu.org--gnu-2005/emacs--unicode--0--patch-81
Merge from emacs--cvs-trunk--0 Patches applied: * emacs--cvs-trunk--0 (patch 532-541) - Update from CVS - Merge from gnus--rel--5.10 * gnus--rel--5.10 (patch 112-115) - Update from CVS
Diffstat (limited to 'lisp/gnus')
-rw-r--r--lisp/gnus/ChangeLog38
-rw-r--r--lisp/gnus/ChangeLog.24
-rw-r--r--lisp/gnus/gnus-agent.el2
-rw-r--r--lisp/gnus/gnus-art.el9
-rw-r--r--lisp/gnus/mm-view.el18
-rw-r--r--lisp/gnus/mml-smime.el2
-rw-r--r--lisp/gnus/nnweb.el22
-rw-r--r--lisp/gnus/spam-report.el47
8 files changed, 104 insertions, 38 deletions
diff --git a/lisp/gnus/ChangeLog b/lisp/gnus/ChangeLog
index 530758aefb0..96052e04c12 100644
--- a/lisp/gnus/ChangeLog
+++ b/lisp/gnus/ChangeLog
@@ -1,3 +1,37 @@
+2005-09-10 Reiner Steib <Reiner.Steib@gmx.de>
+
+ * spam-report.el (spam-report-gmane): Fix generation of spam
+ report URL.
+
+2005-09-10 Simon Josefsson <jas@extundo.com>
+
+ * gnus-agent.el (gnus-agent-synchronize-flags): Make the default
+ t, based on discussion on the ding list with Robert Epprecht
+ <epprecht@solnet.ch>.
+
+2005-09-07 Reiner Steib <Reiner.Steib@gmx.de>
+
+ * spam-report.el (spam-report-gmane): Make it work without
+ X-Report-Spam header. Gmane now only provides Archived-At. This
+ is only used if `spam-report-gmane-use-article-number' is nil.
+ (spam-report-gmane-spam-header): Removed. Not used anymore.
+
+ * nnweb.el (nnweb-google-wash-article): Print a message if article
+ is not available.
+
+2005-09-07 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
+
+ * gnus-art.el (gnus-mime-display-single): Decode text/* parts
+ content before displaying.
+
+2005-09-06 Reiner Steib <Reiner.Steib@gmx.de>
+
+ * mml-smime.el: Remove defvar of gnus-extract-address-components.
+
+2005-09-06 Katsumi Yamaoka <yamaoka@jpl.org>
+
+ * mm-view.el (mm-display-inline-fontify): Disable support modes.
+
2005-09-05 Reiner Steib <Reiner.Steib@gmx.de>
* message.el (message-tab-body-function): Fixed mismatched custom
@@ -5,7 +39,7 @@
* gnus.el (gnus-group-change-level-function): Ditto.
- * gnus-msg.el (gnus-outgoing-message-group): Ditto.
+ * gnus-msg.el (gnus-outgoing-message-group): Ditto.
* gnus-art.el (gnus-signature-limit)
(gnus-article-mime-part-function): Ditto.
@@ -237,8 +271,6 @@
* gnus-util.el (gnus-beginning-of-window): Remove.
(gnus-end-of-window): Remove.
- * lpath.el: Don't bind scroll-margin.
-
2005-07-25 Simon Josefsson <jas@extundo.com>
* pgg.el (pgg-insert-url-with-w3): Don't load w3, it is possible
diff --git a/lisp/gnus/ChangeLog.2 b/lisp/gnus/ChangeLog.2
index 5d7a608054e..f39bf525db8 100644
--- a/lisp/gnus/ChangeLog.2
+++ b/lisp/gnus/ChangeLog.2
@@ -7658,7 +7658,7 @@
* spam.el: more compilation fixes for BBDB
- * spam-stat.el added code from Alex Schroeder <alex@gnu.org>
+ * spam-stat.el: added code from Alex Schroeder <alex@gnu.org>
(spam-stat-reduce-size): Interactive.
(spam-stat-reset): New function.
(spam-stat-save): Interactive.
@@ -12404,7 +12404,7 @@
2001-12-05 Katsumi Yamaoka <yamaoka@jpl.org>
- * mm-view.wl (mm-inline-text): Decode a charset-encoded rich text.
+ * mm-view.el (mm-inline-text): Decode a charset-encoded rich text.
2001-12-04 08:00:00 ShengHuo ZHU <zsh@cs.rochester.edu>
diff --git a/lisp/gnus/gnus-agent.el b/lisp/gnus/gnus-agent.el
index ea45a139ab0..47d1dfd7364 100644
--- a/lisp/gnus/gnus-agent.el
+++ b/lisp/gnus/gnus-agent.el
@@ -115,7 +115,7 @@ If nil, only read articles will be expired."
:group 'gnus-agent
:type 'function)
-(defcustom gnus-agent-synchronize-flags nil
+(defcustom gnus-agent-synchronize-flags t
"Indicate if flags are synchronized when you plug in.
If this is `ask' the hook will query the user."
:version "21.1"
diff --git a/lisp/gnus/gnus-art.el b/lisp/gnus/gnus-art.el
index b07954772d2..3bdc93935bc 100644
--- a/lisp/gnus/gnus-art.el
+++ b/lisp/gnus/gnus-art.el
@@ -4862,7 +4862,14 @@ If displaying \"text/html\" is discouraged \(see
(forward-line -1)
(setq beg (point)))
(gnus-article-insert-newline)
- (mm-insert-inline handle (mm-get-part handle))
+ (mm-insert-inline handle
+ (let ((charset
+ (mail-content-type-get
+ (mm-handle-type handle) 'charset)))
+ (if (eq charset 'gnus-decoded)
+ (mm-get-part handle)
+ (mm-decode-string (mm-get-part handle)
+ charset))))
(goto-char (point-max))))
;; Do highlighting.
(save-excursion
diff --git a/lisp/gnus/mml-smime.el b/lisp/gnus/mml-smime.el
index 25cb3094cbb..2933c14744a 100644
--- a/lisp/gnus/mml-smime.el
+++ b/lisp/gnus/mml-smime.el
@@ -29,8 +29,6 @@
(eval-when-compile (require 'cl))
-(defvar gnus-extract-address-components)
-
(require 'smime)
(require 'mm-decode)
(autoload 'message-narrow-to-headers "message")
diff --git a/lisp/gnus/nnweb.el b/lisp/gnus/nnweb.el
index 85c8d4c5239..d3737cd66fd 100644
--- a/lisp/gnus/nnweb.el
+++ b/lisp/gnus/nnweb.el
@@ -319,12 +319,22 @@ Valid types include `google', `dejanews', and `gmane'.")
;; We have Google's masked e-mail addresses here. :-/
(let ((case-fold-search t))
(goto-char (point-min))
- (delete-region (point-min)
- (1+ (re-search-forward "^<pre>" nil t)))
- (goto-char (point-min))
- (delete-region (- (re-search-forward "^</pre>" nil t) (length "</pre>"))
- (point-max))
- (mm-url-decode-entities)))
+ (if (save-excursion
+ (or (re-search-forward "The requested message.*could not be found."
+ nil t)
+ (not (and (re-search-forward "^<pre>" nil t)
+ (re-search-forward "^</pre>" nil t)))))
+ ;; FIXME: Don't know how to indicate "not found".
+ ;; Should this function throw an error? --rsteib
+ (progn
+ (gnus-message 3 "Requested article not found")
+ (erase-buffer))
+ (delete-region (point-min)
+ (1+ (re-search-forward "^<pre>" nil t)))
+ (goto-char (point-min))
+ (delete-region (- (re-search-forward "^</pre>" nil t) (length "</pre>"))
+ (point-max))
+ (mm-url-decode-entities))))
(defun nnweb-google-parse-1 (&optional Message-ID)
(let ((i 0)
diff --git a/lisp/gnus/spam-report.el b/lisp/gnus/spam-report.el
index 50a564885bb..173306ec55e 100644
--- a/lisp/gnus/spam-report.el
+++ b/lisp/gnus/spam-report.el
@@ -49,12 +49,6 @@ instead."
(regexp :value "^nntp\+.*:gmane\."))
:group 'spam-report)
-(defcustom spam-report-gmane-spam-header
- "^X-Report-Spam: http://\\([^/]+\\)\\(.*\\)$"
- "String matching Gmane spam-reporting header. Two match groups are needed."
- :type 'regexp
- :group 'spam-report)
-
(defcustom spam-report-gmane-use-article-number t
"Whether the article number (faster!) or the header should be used."
:type 'boolean
@@ -103,19 +97,42 @@ undo that change.")
article))
(with-current-buffer nntp-server-buffer
(gnus-request-head article gnus-newsgroup-name)
- (goto-char (point-min))
- (if (re-search-forward spam-report-gmane-spam-header nil t)
- (let* ((host (match-string 1))
- (report (match-string 2))
- (url (format "http://%s%s" host report)))
- (gnus-message 7 "Reporting spam through URL %s..." url)
- (spam-report-url-ping host report))
- (gnus-message 3 "Could not find X-Report-Spam in article %d..."
- article)))))))
+ (let ((case-fold-search t)
+ field host report url)
+ ;; First check for X-Report-Spam because it's more specific to
+ ;; spam reporting than Archived-At. OTOH, all new articles on
+ ;; Gmane don't have X-Report-Spam anymore (unless Lars changes his
+ ;; mind :-)).
+ ;;
+ ;; There might be more than one Archived-At header so we need to
+ ;; find (and transform) the one related to Gmane.
+ (setq field (or (gnus-fetch-field "X-Report-Spam")
+ (gnus-fetch-field "Archived-At")))
+ (setq host (progn
+ (string-match
+ (concat "http://\\([a-z]+\\.gmane\\.org\\)"
+ "\\(/[^:/]+[:/][0-9]+\\)")
+ field)
+ (match-string 1 field)))
+ (setq report (match-string 2 field))
+ (when (string-equal "permalink.gmane.org" host)
+ (setq host "spam.gmane.org")
+ (setq report (gnus-replace-in-string
+ report "/\\([0-9]+\\)$" ":\\1")))
+ (setq url (format "http://%s%s" host report))
+ (if (not (and host report url))
+ (gnus-message
+ 3 "Could not find a spam report header in article %d..."
+ article)
+ (gnus-message 7 "Reporting spam through URL %s..." url)
+ (spam-report-url-ping host report))))))))
(defun spam-report-url-ping (host report)
"Ping a host through HTTP, addressing a specific GET resource using
the function specified by `spam-report-url-ping-function'."
+ ;; Example:
+ ;; host: "spam.gmane.org"
+ ;; report: "/gmane.some.group:123456"
(funcall spam-report-url-ping-function host report))
(defun spam-report-url-ping-plain (host report)
diff --git a/lisp/gnus/mm-view.el b/lisp/gnus/mm-view.el
index 2d78ccab864..ac408aa179f 100644
--- a/lisp/gnus/mm-view.el
+++ b/lisp/gnus/mm-view.el
@@ -476,14 +476,16 @@
(buffer-disable-undo)
(mm-insert-part handle)
(require 'font-lock)
- ;; Inhibit font-lock this time (*-mode-hook might run
- ;; `turn-on-font-lock') so that jit-lock may not turn off
- ;; font-lock immediately after this.
- (let ((font-lock-mode t))
- (funcall mode))
- (let ((font-lock-verbose nil))
- ;; I find font-lock a bit too verbose.
- (font-lock-fontify-buffer))
+ (let ((font-lock-maximum-size nil)
+ ;; Disable support modes, e.g., jit-lock, lazy-lock, etc.
+ (font-lock-mode-hook nil)
+ (font-lock-support-mode nil)
+ ;; I find font-lock a bit too verbose.
+ (font-lock-verbose nil))
+ (funcall mode)
+ ;; The mode function might have already turned on font-lock.
+ (unless (symbol-value 'font-lock-mode)
+ (font-lock-fontify-buffer)))
;; By default, XEmacs font-lock uses non-duplicable text
;; properties. This code forces all the text properties
;; to be copied along with the text.